"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.stringToArray = function (str) {
    return str.match(/[\uD800-\uDBFF][\uDC00-\uDFFF]|[^\uD800-\uDFFF]/g) || [];
};
var SINGLE_ALPHABET_TRANSLATION_LIST = [
    ['a', 'ア'],
    ['b', 'カ'],
    ['c', 'キ'],
    ['d', 'ク'],
    ['e', 'イ'],
    ['f', 'ケ'],
    ['g', 'コ'],
    ['h', 'サ'],
    ['i', 'ウ'],
    ['j', 'シ'],
    ['k', 'ス'],
    ['l', 'セ'],
    ['m', 'ソ'],
    ['n', 'タ'],
    ['o', 'エ'],
    ['p', 'チ'],
    ['q', 'ツ'],
    ['r', 'テ'],
    ['s', 'ト'],
    ['t', 'ナ'],
    ['u', 'オ'],
    ['v', 'ニ'],
    ['w', 'ヌ'],
    ['x', 'ネ'],
    ['y', 'ノ'],
    ['z', 'ハ'],
];
exports.translateSingleAlphabet = function (target) {
    for (var _i = 0, SINGLE_ALPHABET_TRANSLATION_LIST_1 = SINGLE_ALPHABET_TRANSLATION_LIST; _i < SINGLE_ALPHABET_TRANSLATION_LIST_1.length; _i++) {
        var _a = SINGLE_ALPHABET_TRANSLATION_LIST_1[_i], alphabet = _a[0], text = _a[1];
        if (alphabet === target) {
            return text;
        }
    }
    return null;
};
var TWO_ALPHABETS_TRANSLATION_LIST = [
    ['ce', 'ゲ'],
    ['de', 'レ'],
    ['ea', 'ユ'],
    ['er', 'ヨ'],
    ['gr', 'ザ'],
    ['la', 'ヤ'],
    ['lo', 'モ'],
    ['me', 'ヘ'],
    ['mo', 'ビ'],
    ['na', 'ラ'],
    ['ne', 'リ'],
    ['pa', 'ル'],
    ['pl', 'フ'],
    ['re', 'メ'],
    ['ri', 'ミ'],
    ['yo', 'ホ'],
    ['wh', 'ム'],
];
exports.translateTwoAlphabets = function (target) {
    for (var _i = 0, TWO_ALPHABETS_TRANSLATION_LIST_1 = TWO_ALPHABETS_TRANSLATION_LIST; _i < TWO_ALPHABETS_TRANSLATION_LIST_1.length; _i++) {
        var _a = TWO_ALPHABETS_TRANSLATION_LIST_1[_i], alphabet = _a[0], text = _a[1];
        if (alphabet === target) {
            return text;
        }
    }
    return null;
};
exports.translateSingleTaralians = function (target) {
    for (var _i = 0, TWO_ALPHABETS_TRANSLATION_LIST_2 = TWO_ALPHABETS_TRANSLATION_LIST; _i < TWO_ALPHABETS_TRANSLATION_LIST_2.length; _i++) {
        var _a = TWO_ALPHABETS_TRANSLATION_LIST_2[_i], alphabet = _a[0], text = _a[1];
        if (text === target) {
            return alphabet;
        }
    }
    for (var _b = 0, SINGLE_ALPHABET_TRANSLATION_LIST_2 = SINGLE_ALPHABET_TRANSLATION_LIST; _b < SINGLE_ALPHABET_TRANSLATION_LIST_2.length; _b++) {
        var _c = SINGLE_ALPHABET_TRANSLATION_LIST_2[_b], alphabet = _c[0], text = _c[1];
        if (text === target) {
            return alphabet;
        }
    }
    return null;
};
var TOKEN_TYPES = [
    {
        type: 'properName',
        pattern: /^('[^']+?'|"[^"]+?")/,
    },
    {
        type: 'word',
        pattern: /^[^\s]+/,
    },
    {
        type: 'spaces',
        pattern: /^\s+/,
    },
];
exports.lexer = function (text) {
    var tokens = [];
    var restText = text;
    while (restText !== '') {
        var analyzeSuccessed = false;
        for (var _i = 0, TOKEN_TYPES_1 = TOKEN_TYPES; _i < TOKEN_TYPES_1.length; _i++) {
            var _a = TOKEN_TYPES_1[_i], pattern = _a.pattern, type = _a.type;
            var matched = pattern.exec(restText);
            if (matched !== null) {
                restText = restText.replace(pattern, '');
                analyzeSuccessed = true;
                tokens.push({
                    type: type,
                    text: matched[0],
                });
                break;
            }
        }
        if (analyzeSuccessed === false) {
            throw new Error('Lexical analysis failed. This is an unexpected error.');
        }
    }
    return tokens;
};
